@@ -1,4 +1,4 @@
 from .market import Market
 from .odds import Odds
 
-__all__ = [Market, Odds]
+__all__ = ["Market", "Odds"]
